@@ -91,7 +91,7 @@ HackaMol::Dihedral - Dihedral Angle class for HackaMol
 
 =head1 VERSION
 
-version 0.00_02
+version 0.00_03
 
 =head1 SYNOPSIS
 
@@ -158,7 +158,7 @@ no arguments. returns the angle (degrees) between the planes containing
 no arguments. returns the angle (radians) between the planes containing 
 (atom1,atom2,atom3) and (atom2, atom3, atom4). 
 
-=head2 improper_dihe_energy torsion_energy
+=head2 improper_dihe_energy 
 
 arguments, as many as you want. Calculates energy using the 
 improper_dihe_energy_func described below, if the attribute, dihe_fc > 0.  
@@ -168,6 +168,10 @@ The improper_dihe_energy method calls the improper_dihe_energy_func as follows:
 
 which will pass $self and that in @_ array to improper_dihe_energy_func, which, similar to the Bond and Angle classes, can be redefined. torsion_energy is analogous.
 
+=head2 torsion_energy
+
+analogous to improper_dihe_energy
+
 =head1 ATTRIBUTES
 
 =head2 atoms
@@ -195,11 +199,15 @@ isa Num that is lazy and rw. default = 0.  force constant for harmonic bond pote
 
 isa Num that is lazy and rw. default = 0.  Equilibrium dihedral angle.  
 
-=head2 improper_dihe_energy_func torsion_energy_func
+=head2 improper_dihe_energy_func 
 
 isa CodeRef that is lazy and rw. default uses builder to generate a 
 harmonic potential for the improper_dihedral and a torsion potential. 
 
+=head2 torsion_energy_func
+
+analogous to improper_dihe_energy_func 
+
 =head1 SEE ALSO
 
 =over 4
